##  Enter the Copied Credentials in SAP LeanIX
  1. Add the Entra ID integration in SAP LeanIX. For more, see [Setting Up Out-of-the-Box Integrations](https://help.sap.com/docs/leanix/ea/discovery-and-integrations?locale=en-US&state=PRODUCTION&version=CLOUD#loio275ba7437a441014af4ea67e4bf11105__setting_up_out-of-the-box_integrations).
  2. In the configuration, choose a name for the integration and select the type of capabilities or data you want to get from Microsoft Entra ID. SaaS Discovery is enabled by default, and you can optionally enable Usage Indication.
  3. Enter the credentials copied from the Azure admin portal into the corresponding fields.
![Entering the Azure Admin Portal Credentials in SAP LeanIX](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274150467a441014944784d193b6cd90_LowRes.png)
Entering the Required Credentials in SAP LeanIX
  4. Click Finish and wait for the connection to be established.


YesNo
Send
